Name:           javassist
Version:        3.30.2
Release:        %mkrel 2
Summary:        Java Programming Assistant for Java bytecode manipulation
Group:          Development/Java
License:        MPLv1.1 or LGPLv2+ or ASL 2.0

%global upstream_version rel_%(sed s/\\\\./_/g <<<"%{version}")_ga

URL:            https://www.javassist.org/
Source0:        https://github.com/jboss-%{name}/%{name}/archive/refs/tags/%{upstream_version}.tar.gz

BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.hamcrest:hamcrest-all)

%description
Javassist enables Java programs to define a new class at runtime and to
modify a class file when the JVM loads it. Unlike other similar
bytecode editors, Javassist provides two levels of API: source level
and bytecode level. If the users use the source-level API, they can
edit a class file without knowledge of the specifications of the Java
bytecode. The whole API is designed with only the vocabulary of the
Java language. You can even specify inserted bytecode in the form of
source text; Javassist compiles it on the fly. On the other hand, the
bytecode-level API allows the users to directly edit a class file as
other editors.


%package javadoc
Summary:        Javadocs for javassist

%description javadoc
javassist development documentation.


%prep
%setup -q -n %{name}-%{upstream_version}

# remove unnecessary maven plugins
%pom_remove_plugin :maven-source-plugin

# disable profiles that only add com.sun:tools dependency
%pom_xpath_remove "pom:profiles"

# add compatibility alias for old maven artifact coordinates
%mvn_alias : %{name}:%{name}

# add compatibility symlink for old classpath
%mvn_file : %{name}


%build
%mvn_build

# remove bundled jar and class files *after* they were used for running tests
rm javassist.jar src/test/resources/*.jar
find src/test -name "*.class" -print -delete


%install
%mvn_install


%files -f .mfiles
%license License.html
%doc README.md

%files javadoc -f .mfiles-javadoc
%license License.html




%changelog
* Sun Jun 29 2025 umeabot <umeabot> 3.30.2-2.mga10
+ Revision: 2223414
- Mageia 10 Mass Rebuild

* Fri May 24 2024 ns80 <ns80> 3.30.2-1.mga10
+ Revision: 2067068
- new version 3.30.2 for java 21

* Mon Dec 12 2022 daviddavid <daviddavid> 3.29.0-1.mga9
+ Revision: 1920919
- Update javassist to 3.29.0 (#2085504)
- Inner.java test no longer dependent on deprecated java.rmi
- Changed source URL to actual one

* Sat Mar 26 2022 umeabot <umeabot> 3.27.0-2.mga9
+ Revision: 1827702
- Mageia 9 Mass Rebuild

* Mon Mar 01 2021 daviddavid <daviddavid> 3.27.0-1.mga9
+ Revision: 1694786
- Update to version 3.27.0

* Sat Sep 05 2020 daviddavid <daviddavid> 3.21.0-1.mga8
+ Revision: 1622318
- Rebase to 3.21.0
- Rebuilt for JDK-11

* Tue Feb 11 2020 umeabot <umeabot> 3.18.1-8.mga8
+ Revision: 1490935
- Mageia 8 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 3.18.1-7.mga7
+ Revision: 1262703
- Mageia 7 Mass Rebuild

* Wed Mar 02 2016 neoclust <neoclust> 3.18.1-6.mga6
+ Revision: 981851
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 3.18.1-5.mga6
+ Revision: 976522
- First rebuild of the java stack
- sync package javassist with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Tue Jan 13 2015 pterjan <pterjan> 3.18.1-1.mga5
+ Revision: 810554
- Sync with Fedora 21 (update to 3.18.1)

* Wed Oct 15 2014 umeabot <umeabot> 3.16.1-4.mga5
+ Revision: 746028
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
- Mageia 4 Mass Rebuild

* Sat Sep 28 2013 dmorgan <dmorgan> 3.16.1-1.mga4
+ Revision: 488603
- New version

* Sat Jan 12 2013 umeabot <umeabot> 3.14.0-5.mga3
+ Revision: 354864
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 03 2011 gil <gil> 3.14.0-4.mga2
+ Revision: 151297
- * corrected/modified depmap
  * rebuilt with mvn 3 support

* Thu Apr 28 2011 dmorgan <dmorgan> 3.14.0-3.mga1
+ Revision: 92535
- Rebuild after bootstrapping
- imported package javassist


* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.14.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Nov 4 2010 Alexander Kurtakov <akurtako@redhat.com> 3.14.0-1
- Update to 3.14.0 upstream version.
- Various fixes in preparation for merge review.

* Fri Feb 12 2010 Alexander Kurtakov <akurtako@redhat.com> 3.9.0-7
- Add maven-doxia BRs.

* Fri Feb 12 2010 Alexander Kurtakov <akurtako@redhat.com> 3.9.0-6
- Remove not needed BR. Fixes rhbz#539176.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.9.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.9.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Jan 27 2009 John5342 <john5342 at, fedoraproject.org> - 3.9.0-3
- Correct group id for maven depmap

* Mon Jan 26 2009 John5342 <john5342 at, fedoraproject.org> - 3.9.0-2
- Build using maven and install maven stuff (fixes bug 480428)

* Tue Dec 16 2008 Sandro Mathys <red at fedoraproject.org> - 3.9.0-1
- initial build
